<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.0">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>バージョン情報...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>情報(&amp;I)</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>翻訳者(&amp;T)</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>ライセンス(&amp;L)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer の YouTube%1 ブラウザー</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>ポータブル エディション</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Qt %1 でコンパイルされました (%2 を使用しています)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>更新のためには私たちの Web にアクセスします:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>多くの方に翻訳でご貢献いただきました。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>SMTube をお使いの言語に翻訳することもできます。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>%1 にアクセスして翻訳チームに参加してください。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Transifex チームの翻訳者をご覧になるにはここをクリックします</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="138"/>
        <source>Home</source>
        <translation>ホーム</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="141"/>
        <source>Navigation</source>
        <translation>ナビゲーション</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="149"/>
        <source>Zoom +</source>
        <translation>拡大</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="153"/>
        <source>Zoom -</source>
        <translation>縮小</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="157"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="160"/>
        <source>&amp;Navigation</source>
        <translation>操作(&amp;N)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="172"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="173"/>
        <source>Toolbar</source>
        <translation>ツール バー</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="177"/>
        <source>Statusbar</source>
        <translation>ステータス バー</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="198"/>
        <source>&amp;Update YouTube playback support</source>
        <translation>YouTube 再生サポートの更新(&amp;U)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="200"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation>YouTube 再生サポートのインストール / 更新(&amp;I)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="206"/>
        <source>&amp;About SMTube</source>
        <translation>SMTube のバージョン情報(&amp;A)</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="331"/>
        <source>Download video using an external service</source>
        <translation>外部サービスを使用して動画をダウンロードする</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="332"/>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="578"/>
        <source>No video found</source>
        <translation>動画が見つかりません</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="579"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>この動画の URL を見つけることができませんでした。</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="610"/>
        <source>About...</source>
        <translation>バージョン情報...</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="611"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer の YouTube%1 ブラウザー</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="317"/>
        <source>Loading... %1%</source>
        <translation>読み込み中... %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation>ダウンロードしています...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation>%1 へ接続しています</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation>YouTube のコードは正常にインストールされました。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation>インストールされたバージョン: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation>%1 を保存できません。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>ファイルのダウンロード中にエラーが発生しました:&lt;br&gt;%1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation>%1 は youtube-dl との通信に失敗しました。インストールされていないか正しく動作しない可能性があります。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>この動画の URL を見つけることができませんでした。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation>youtube-dl を更新する必要がある可能性があります。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation>YouTube 動画を再生するのに、%1 は youtube-dl という外部アプリケーションを必要とします。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation>このコンポーネントは頻繁に更新される必要があります。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation>単純に SMPlayer を再インストールして更新できます。インストーラーは最新バージョンをダウンロードおよびインストールします。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation>YouTube サポートのインストール / 更新</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="232"/>
        <source>In order to play YouTube videos, %1 needs the help of an external application.</source>
        <translation>YouTube ビデオを再生するのに、%1 は外部アプリケーションの支援を必要とします。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="233"/>
        <source>%1 can download and install this application for you.</source>
        <translation>%1 はこのアプリケーションをダウンロードおよびインストールします。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="234"/>
        <source>It will be downloaded from the official website and installed as %1.</source>
        <translation>公式 Web サイトからダウンロードされ %1 としてインストールされます。</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="235"/>
        <source>Would you like to proceed?</source>
        <translation>続行しますか?</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="239"/>
        <location filename="../codedownloader.cpp" line="242"/>
        <source>Install YouTube support?</source>
        <translation>YouTube サポートをインストールしますか?</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>全般(&amp;G)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation>追加(&amp;D)...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="178"/>
        <source>&amp;Players</source>
        <translation>プレーヤー(&amp;P)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="226"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="191"/>
        <source>Up</source>
        <translation>上へ</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>再生</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>優先する品質(&amp;Q):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation>サイト</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation>サイト(&amp;S):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation>編集(&amp;T)...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation>削除(&amp;L)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="152"/>
        <source>YouTube support application</source>
        <translation>YouTube サポート アプリケーション</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="237"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="261"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="274"/>
        <source>A&amp;dd predefined players</source>
        <translation>定義済みプレーヤーの追加(&amp;D)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="310"/>
        <source>&amp;Interface</source>
        <translation>インターフェイス(&amp;I)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="318"/>
        <source>&amp;Style:</source>
        <translation>スタイル(&amp;S):</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="354"/>
        <source>Font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="368"/>
        <source>C&amp;hange...</source>
        <translation>変更(&amp;H)...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>外部サービスを使用して動画をダウンロードする(&amp;E)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="202"/>
        <source>Down</source>
        <translation>下へ</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="82"/>
        <source>Default</source>
        <translation>既定</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="460"/>
        <source>yt-dlp (based on youtube-dl with improvements)</source>
        <translation>yt-dlp (youtube-dl の改良版)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="478"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>ファイルまたはフォルダーを選択するにはクリックします</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>YouTube で開く(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>リンクの保存(&amp;S)...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>クリップボードへリンクをコピー(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>このウィンドウでリンクを開く</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>クリップボードへテキストをコピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>新しいウィンドウでリンクを開く(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>再生するアプリケーション(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation>オーディオを再生するアプリケーション(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>%1 で再生(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="145"/>
        <source>Play &amp;audio with %1</source>
        <translation>%1 でオーディオを再生(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="154"/>
        <source>Play video with a &amp;web browser</source>
        <translation>Web ブラウザーでビデオを再生(&amp;W)</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>プレーヤーの編集</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>名前(&amp;N):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>実行ファイル(&amp;E):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>パラメーター(&amp;P):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>動画サイト対応のプレーヤー(&amp;V)</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>オンライン TV 対応のプレーヤー(&amp;O)</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>優先する品質(&amp;Q):</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>メニューに追加(&amp;M):</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>オーディオ</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>ビデオとオーディオ</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>既定</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../version.cpp" line="48"/>
        <source>%1 (revision %2) %3</source>
        <translation>%1 (リビジョン %2) %3</translation>
    </message>
    <message>
        <location filename="../version.cpp" line="50"/>
        <source>%1 (revision %2)</source>
        <translation>%1 (リビジョン %2)</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation>サイトの編集</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>名前(&amp;N):</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation>ホーム ページの URL(&amp;H):</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation>検索 URL(&amp;S):</translation>
    </message>
</context>
</TS>